# Асинхронный планировщик задач

Простой асинхронный планировщик задач с минимумом зависимостей

## Установка

```bash
pip install async_scheduler
```

## Использование

см. демонстрационное приложение в demo/
